# Exceptions

List of exception classes provided by `flask_restly`:

1. BadRequest
1. Conflict
1. Forbidden
1. InternalServerError
1. NotAcceptable
1. NotFound
1. NotImplemented
1. TooManyRequests
1. Unauthorized
1. UnprocessableEntity

```python
from flask_restly.exception import *
```

Simple example of usage can be found in `errors.py` example.
